=================
pytest-messenger
=================

ex pytest-slack

.. image:: https://img.shields.io/pypi/v/pytest-messenger.svg
        :target: https://pypi.python.org/pypi/pytest-messenger

.. image:: https://codecov.io/gh/pytest-dev/pytest-messenger/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/pytest-dev/pytest-messenger

.. image:: https://pyup.io/repos/github/pytest-dev/pytest-messenger/shield.svg
        :target: https://pyup.io/repos/github/pytest-dev/pytest-messenger/
        :alt: Updates




Pytest to IM reporting plugin

Supported messengers:

* `Slack <https://github.com/pytest-dev/pytest-messenger/wiki/Slack>`_
* `Ding Talk <https://github.com/pytest-dev/pytest-messenger/wiki/DingTalk>`_
* Telegram - soon


.. image:: https://raw.githubusercontent.com/pytest-dev/pytest-messenger/master/img/demo.gif


Requirements
------------

* Requests



Installation
------------

You can install "pytest-messenger" via `pip`_::

    $ pip install pytest-messenger





Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.


Credits
-------

[ ~ Dependencies scanned by PyUp.io ~ ]

.. _`file an issue`: https://github.com/pytest-dev/pytest-messenger/issues
.. _`pytest`: https://github.com/pytest-dev/pytest
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.python.org/pypi/pip/
